@@ -14,6 +14,7 @@
 #include <unistd.h>
 #include <termios.h>
 #include <time.h>
+#include <sys/time.h>
 
 #ifndef INLINE
 # ifdef __GNUC__
@@ -39,7 +40,8 @@
 extern struct termios original_termios;
 void *allocate(const void *, unsigned bytes);	/* mem.c */
 void *allocate0(unsigned bytes);
-void die(const char *, ...);			/* die.c */
+void depart(int);				/* die.c */
+void die(const char *, ...);
 void message(const char *, ...);
 int child(int *stdfd, unsigned stdfds, const char *argv[]);	/* child.c */
 int multiplexor(int block);
