@@ -28,8 +28,10 @@
 #define CTL_RESETCOLORS	CSI "39;49m"
 #define CTL_GOTO	CSI "%d;%df"
 #define CTL_ERASEALL	CSI "2J"
+#if 0 /* broken on Apple Terminal, dammit */
 #define CTL_ERASETOEND	CSI "J"
 #define CTL_ERASELINE	CSI "K"
+#endif
 #define CTL_ERASECOLS	CSI "%dX"
 #define CTL_DELCOLS	CSI "%uP"
 #define CTL_DELLINES	CSI "%uM"
@@ -39,10 +41,11 @@
 #define CTL_CURSORPOS	CSI "6n"
 #define FG_COLOR	30
 #define BG_COLOR	40
-#define XTERM_TITLE	OSC "2;%s" ESC "\\"
+#define XTERM_TITLE	OSC "0;%s" ST
+/* was: #define XTERM_TITLE	OSC "2;%s" ESC "\\" */
 #define XTERM_ALTSCREEN	CSI "?47h"
 #define XTERM_REGSCREEN	CSI "?47l"
-#define XTERM_BCKISDEL	CSI "?67h"
+#define XTERM_BCKISDEL	CSI "?67l"
 
 
 struct cell {
@@ -321,20 +324,26 @@ void display_erase(struct display *display, unsigned row, unsigned column,
 
 doit:	foreground_color(display, fgrgba);
 	background_color(display, bgrgba);
-	if (column + columns == display->columns)
-		if (!column && rows == display->rows - row) {
-			moveto(display, row, column);
-			outs(display, CTL_ERASETOEND);
-		} else
-			for (r = 0; r < rows; r++) {
-				moveto(display, row + r, column);
-				outs(display, CTL_ERASELINE);
-			}
-	else
+
+#ifdef CTL_ERASETOEND
+	if (!column && columns == display->columns && row + rows == display->rows) {
+		moveto(display, row, column);
+		outs(display, CTL_ERASETOEND);
+	} else
+#endif
+#ifdef CTL_ERASELINE
+	if (column + columns == display->columns) {
 		for (r = 0; r < rows; r++) {
 			moveto(display, row + r, column);
-			outf(display, CTL_ERASECOLS, columns);
+			outs(display, CTL_ERASELINE);
 		}
+	} else
+#endif
+	for (r = 0; r < rows; r++) {
+		moveto(display, row + r, column);
+		outf(display, CTL_ERASECOLS, columns);
+	}
+
 	for (; rows--; row++)
 		fill(display, row, column, columns, ' ', fgrgba, bgrgba);
 }
@@ -657,7 +666,7 @@ static void sigwinch(int signo, siginfo_t *info, void *data)
 		old_sigwinch(signo, info, data);
 }
 
-#ifndef __linux__
+#if !(defined __linux__ || defined __APPLE__)
 void cfmakeraw(struct termios *termios)
 {
 	termios->c_iflag &= ~(IGNBRK|BRKINT|PARMRK|ISTRIP|INLCR|IGNCR|IXON);
@@ -691,7 +700,8 @@ struct display *display_init(void)
 
 	display_list = display;
 	display->inbuf_bytes = display->outbuf_bytes = 0;
-	display->is_xterm = (term = getenv("TERM")) && !strcmp(term, "xterm");
+	display->is_xterm = (term = getenv("TERM")) &&
+			    !strncmp(term, "xterm", 5);
 	display_reset(display);
 	display_sync(display);
 	return display;
@@ -705,6 +715,8 @@ void display_end(struct display *display)
 		return;
 
 	display_title(display, NULL);
+	set_color(display, ~0 /*default*/, BG_COLOR);
+	set_color(display, ~0 /*default*/, FG_COLOR);
 	if (display->is_xterm)
 		outs(display, XTERM_REGSCREEN);
 	else
